# libpythonpro
Módulo para exemplificar construção de projetos Python no curso PyTools

Nesse curso é ensinado como contribuir com projetos de código aberto.

Link para o curso [Python Pro](https://pythonpro.com.br/)

[![Python application](https://github.com/faustoroger/libpythonpro/actions/workflows/python-app.yml/badge.svg?branch=master)](https://github.com/faustoroger/libpythonpro/actions/workflows/python-app.yml)
[![Updates](https://pyup.io/repos/github/faustoroger/libpythonpro/shield.svg)](https://pyup.io/repos/github/faustoroger/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/faustoroger/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/faustoroger/libpythonpro/)
[![codecov](https://codecov.io/gh/faustoroger/libpythonpro/branch/master/graph/badge.svg?token=7TWQTRD2RK)](https://codecov.io/gh/faustoroger/libpythonpro)

Suportada versão 3 de Python

Para instalar:

```console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt
```

Para conferir qualidade de código:

```console
flake8
```

Tópicos a serem abordados:
 1. Git
 2. Virtualenv
 3. Pip